@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2002 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,5 +21,6 @@
  * dxcc.h
  */
 
-void loaddxcc(void);
-void updatedxccframe(gchar *callsign);
+gint readctydata (void);
+gint readxlogdata (void);
+void updatedxccframe (gchar * callsign);
