@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2002 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,4 +21,4 @@
  * gc.h
  */
 
-gchar *gc(gint units, gchar *qth, gchar *dest);
+gchar *gc (gint units, gchar * qth, gdouble DEST_Lat, gdouble DEST_Long);
