@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2002 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,17 @@
  */
 
 #if WANT_HAMLIB
-	GList *riglist_get_list(void);
-	gint get_rigid(gchar *rig);
-	gint get_riginfo(void);
-	void loadsmeter(GtkWidget *widget);
-	void sethamlibwidgets(gint status);
-	gboolean on_smeterdrawingarea_configure_event(GtkWidget *widget, GdkEventConfigure *event, gpointer user_data);
-	gboolean on_smeterdrawingarea_expose_event(GtkWidget *widget, GdkEventExpose *event, gpointer user_data);
-	void on_mainwindow_show(GtkWidget *widget, gpointer user_data);
+GList *riglist_get_list (void);
+gint get_rigid (gchar * rig);
+gchar *getrigmode (gint mode);
+gint get_riginfo (void);
+void loadsmeter (GtkWidget * widget);
+void sethamlibwidgets (gint status);
+gboolean on_smeterdrawingarea_configure_event (GtkWidget * widget,
+					       GdkEventConfigure * event,
+					       gpointer user_data);
+gboolean on_smeterdrawingarea_expose_event (GtkWidget * widget,
+					    GdkEventExpose * event,
+					    gpointer user_data);
+void on_mainwindow_show (GtkWidget * widget, gpointer user_data);
 #endif
