@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2002 Joop Stakenborg <pa4tu@amsat.org>
+ * Copyright (C) 2001-2003 Joop Stakenborg <pa4tu@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,18 +24,22 @@
 #include "logfile/logfile.h"
 
 /* struct for every log window */
-typedef struct logtype {
-	gint id;
-	GtkWidget *scrolledwindow;
-	GtkWidget *clist;
-	GtkWidget *label;
-	gchar *logname;
-	gboolean logchanged;
-	gint qsos;
-} logtype;
+typedef struct logtype
+{
+  GtkWidget *scrolledwindow;
+  GtkWidget *clist;
+  GtkWidget *label;
+  gchar *logname;
+  gboolean logchanged;
+  gint qsos;
+  gint columns;
+  gint logfields[QSO_FIELDS];
+}
+logtype;
 
 
-gchar *logname(gchar *filename);
-gint fillin_clist(LOGDB *handle, qso_t q[], gpointer arg);
-logtype *new_logwindow(gint id);
-GString *getlogs(gchar *dir);
+gchar *logname (gchar * filename);
+gint fillin_clist (LOGDB * handle, qso_t q[], gpointer arg);
+logtype *openlog (LOGDB * lp, gchar * name, gint page);
+void savelog (gpointer arg, gchar * logfile, gint type);
+GString *getlogs (gchar * dir, gint filetype);
